
Data Exchange Layer (DXL) Python SDK Documentation
==================================================

Introduction
-------------------

.. toctree::
	:maxdepth: 1

	overview
	architecture
	features
	integrationtypes

Installation
------------

.. toctree::
	:maxdepth: 1

	installation

Provisioning
------------

.. toctree::
	:maxdepth: 1

	certcreation
  	epocaimport
	epobrokercertsexport
	epobrokerlistexport

Python API
----------

.. toctree::
    :titlesonly:

    dxlclient

Samples
-------

Configuration

.. toctree::
	:maxdepth: 1

    sampleconfig

Basic

.. toctree::
	:maxdepth: 1

    basiceventsexample
    basicserviceexample

Advanced

.. toctree::
	:maxdepth: 1

	advancedeventsexample
	advancedserviceexample

Service Wrapper

.. toctree::
	:maxdepth: 1

	servicewrapperexample

Threat Intelligence Exchange (TIE)

.. toctree::
	:maxdepth: 1

	tiefilerepexample

McAfee Active Response (MAR)

.. toctree::
	:maxdepth: 1

	marsearchexample
	marsendauth

Authorization
-------------------

.. toctree::
	:maxdepth: 1

	topicauthoverview
	topicauthgroupcreation
	topicauthgrouprestrictions
